@@ -39,10 +39,13 @@ from options import options
 
 import ConfigParser
 
+import threading
+import time
+
 #
 # Upgrade this number to force the client to ask the survey
 #
-SURVEY_VERSION = '1'
+SURVEY_VERSION = '2'
 
 def _search_file(x, dir='path.share'):
 	tests = [
@@ -194,20 +197,37 @@ def upload_email(email):
 		pass
 	return True
 
-def upload_data(email, data, type='survey', supportid=''):
-	try:
-		import urllib
-		args = urllib.urlencode([('email',email),('type',type),('supportid',supportid),('data',data)])
-		fp = urllib.urlopen('http://tinyerp.com/scripts/survey.php', args)
-		fp.read()
-		fp.close()
-		return True
-	except:
-		return False
+class upload_data_thread(threading.Thread):
+	def __init__(self, email, data, type, supportid):
+		self.args = [('email',email),('type',type),('supportid',supportid),('data',data)]
+		super(upload_data_thread,self).__init__()
+	def run(self):
+		try:
+			import urllib
+			args = urllib.urlencode(self.args)
+			fp = urllib.urlopen('http://tinyerp.com/scripts/survey.php', args)
+			fp.read()
+			fp.close()
+		except:
+			pass
+
+
+def upload_data(email, data, type='survey2', supportid=''):
+	a = upload_data_thread(email, data, type, supportid)
+	a.start()
+	#try:
+	#	import urllib
+	#	args = urllib.urlencode([('email',email),('type',type),('supportid',supportid),('data',data)])
+	#	fp = urllib.urlopen('http://tinyerp.com/scripts/survey.php', args)
+	#	fp.read()
+	#	fp.close()
+	#	return True
+	#except:
+	#	return False
 
 def terp_survey():
 	if options.options['survey.position']==SURVEY_VERSION:
-		return True
+		return False
 	import pickle
 	widnames = ('country','role','industry','employee','hear','system','opensource')
 	winglade = glade.XML(common.terp_path("terp.glade"), "dia_survey", gettext.textdomain())
@@ -218,24 +238,27 @@ def terp_survey():
 		wid = winglade.get_widget('combo_'+widname)
 		wid.child.set_text('(choose one)')
 		wid.child.set_editable(False)
-	win.run()
-	email =  winglade.get_widget('entry_email').get_text()
-	if '@' in email:
-		upload_email(email)
-	result = {}
-	for widname in widnames:
-		wid = winglade.get_widget('combo_'+widname)
-		result[widname] = wid.child.get_text()
-	result['plan_use']=winglade.get_widget('check_use').get_active()
-	result['plan_sell']=winglade.get_widget('check_sell').get_active()
+	res = win.run()
+	if res==gtk.RESPONSE_OK:
+		email =  winglade.get_widget('entry_email').get_text()
+		if '@' in email:
+			upload_email(email)
+		result = {}
+		for widname in widnames:
+			wid = winglade.get_widget('combo_'+widname)
+			result[widname] = wid.child.get_text()
+		result['plan_use']=winglade.get_widget('check_use').get_active()
+		result['plan_sell']=winglade.get_widget('check_sell').get_active()
 
-	buffer = winglade.get_widget('textview_comment').get_buffer()
-	iter_start = buffer.get_start_iter()
-	iter_end = buffer.get_end_iter()
-	result['note'] = buffer.get_text(iter_start,iter_end,False)
-	win.destroy()
-	result_pick = pickle.dumps(result)
-	upload_data(email, result_pick, type='SURVEY '+str(SURVEY_VERSION))
+		buffer = winglade.get_widget('textview_comment').get_buffer()
+		iter_start = buffer.get_start_iter()
+		iter_end = buffer.get_end_iter()
+		result['note'] = buffer.get_text(iter_start,iter_end,False)
+		result_pick = pickle.dumps(result)
+		win.destroy()
+		upload_data(email, result_pick, type='SURVEY '+str(SURVEY_VERSION))
+	else:
+		win.destroy()
 	return True
 
 def test():
@@ -441,3 +464,44 @@ def ask(question):
 
 def dec_trunc(nbr, prec=2):
 	return round(nbr * (10 ** prec)) / 10**prec
+
+class progress(object):
+	class _progress_thread(threading.Thread):
+		def __init__(self, win, pb_widget):
+			self.running=True
+			self.waiting = True
+			self.win=win
+			self.pb_widget=pb_widget
+			super(progress._progress_thread, self).__init__()
+		
+		def run(self):
+			time.sleep(2)
+			if not self.running:
+				self.waiting = False
+				return
+			self.win.show()
+			self.pb_widget.set_pulse_step(0.005)
+			while self.running:
+				self.pb_widget.pulse()
+				gtk.main_iteration()
+				time.sleep(0.01)
+			self.waiting = False
+
+		def stop(self):
+			self.running=False
+			while not self.waiting:
+				time.sleep(0.01)
+
+	def __init__(self):
+		self.dialog = glade.XML(common.terp_path("terp.glade"), "win_progress", gettext.textdomain())
+		self.win = self.dialog.get_widget('win_progress')
+		self.pb_widget = self.dialog.get_widget('progressbar')
+		self.thread=self._progress_thread(self.win, self.pb_widget)
+		
+	def start(self):
+		self.thread.start()
+
+	def stop(self):
+		self.thread.stop()
+		self.win.destroy()
+		gtk.main_iteration()
