@@ -79,6 +79,8 @@ class main(service.Service):
 		self._exec_action(res,datas)
 
 	def _exec_action(self, action, datas):
+		if 'type' not in action:
+			return
 		if action['type']=='ir.actions.act_window':
 			for key in ('res_id', 'res_model', 'view_type','view_mode'):
 				datas[key] = action.get(key, datas.get(key, None))
@@ -102,6 +104,8 @@ class main(service.Service):
 			#	del rpc.session.context[key]
 
 		elif action['type']=='ir.actions.wizard':
+			if 'window' in datas:
+				del datas['window']
 			wizard.execute(action['wiz_name'], datas)
 
 		elif action['type']=='ir.actions.report.custom':
