@@ -37,17 +37,24 @@ import common
 
 from widget.screen import Screen
 
+
 class dialog(object):
 	def __init__(self, arch, fields, state, name):
 		buttons = []
 		self.states=[]
-		for x in state:
-			buttons.append(x[1])
-			buttons.append(len(self.states))
-			self.states.append(x[0])
 		self.dia = gtk.Dialog('Tiny ERP', None,
-			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
-			tuple(buttons))
+			gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT)
+		for x in state:
+			#buttons.append(x[1])
+			#buttons.append(gtk.RESPONSE_CANCEL)#len(self.states))
+
+			but = gtk.Button(x[1])
+			if len(x)==3:
+				icon = gtk.Image()
+				icon.set_from_stock(x[2], gtk.ICON_SIZE_BUTTON)
+				but.set_image(icon)
+			self.dia.add_action_widget(but,len(self.states))
+			self.states.append(x[0])
 
 		val = {}
 		for f in fields:
@@ -60,7 +67,7 @@ class dialog(object):
 		self.screen.current_model.set(val)
 
 		x,y = self.screen.screen_container.size_get()
-		self.screen.widget.set_size_request(x,y)
+		self.screen.widget.set_size_request(x + 20, min(750, y+25))
 
 		self.dia.vbox.pack_start(self.screen.widget)
 		self.dia.set_title(self.screen.current_view.title)
@@ -87,7 +94,13 @@ def execute(action, datas, state='init'):
 		datas['form'] = {}
 	wiz_id = rpc.session.rpc_exec_auth('/wizard', 'create', action)
 	while state!='end':
-		res = rpc.session.rpc_exec_auth('/wizard', 'execute', wiz_id, datas, state, rpc.session.context)
+		thread_progress=common.progress()
+		thread_progress.start()
+		try:
+			res = rpc.session.rpc_exec_auth('/wizard', 'execute', wiz_id, datas, state, rpc.session.context)
+		finally:
+			thread_progress.stop()
+
 		if 'datas' in res:
 			datas['form'].update( res['datas'] )
 		if res['type']=='form':
