@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: form.py 4017 2006-09-04 08:44:06Z pinky $
+# $Id: form.py 4444 2006-11-05 11:12:27Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -28,11 +28,11 @@
 ##############################################################################
 
 import types
+import gettext
 
 import gtk
 import gobject
 from gtk import glade
-import gettext
 
 import rpc
 import win_selection
@@ -63,14 +63,14 @@ class form(object):
 		fields = {}
 		self.model = model
 		self.previous_action = None
-		self.glade = glade.XML(common.terp_path("terp.glade"),'win_form_container')
+		self.glade = glade.XML(common.terp_path("terp.glade"),'win_form_container',gettext.textdomain())
 		self.widget = self.glade.get_widget('win_form_container')
 		self.widget.show_all()
 		self.fields = fields
 		self.domain = domain
 		self.context = context
 
-		self.screen = Screen(self.model, view_type=view_type, context=self.context, view_ids=view_ids, domain=domain)
+		self.screen = Screen(self.model, view_type=view_type, context=self.context, view_ids=view_ids, domain=domain, hastoolbar=options.options['form.toolbar'])
 		self.screen.signal_connect(self, 'record-message', self._record_message)
 		oregistry.add_receiver('misc-message', self._misc_message)
 
@@ -120,7 +120,7 @@ class form(object):
 	def sig_goto(self, *args):
 		if not self.modified_save():
 			return
-		glade2 = glade.XML(common.terp_path("terp.glade"),'dia_goto_id')
+		glade2 = glade.XML(common.terp_path("terp.glade"),'dia_goto_id',gettext.textdomain())
 		win = glade2.get_widget('dia_goto_id')
 		widget = glade2.get_widget('goto_spinbutton')
 		response = win.run()
@@ -259,7 +259,7 @@ class form(object):
 			if not modification:
 				self.screen.new()
 		else:
-			self.message_state(_('Invalid form, correct red fields !'))
+			self.message_state(_('Invalid form !'))
 		return bool(id)
 
 	def sig_previous(self, widget=None):
