@@ -56,6 +56,8 @@ class Printer(object):
 			content = os.listdir(dir)
 			for prog in progs[:]:
 				if prog in content:
+					return os.path.join(dir, prog)#prog
+					
 					progs.remove(prog)
 					found[prog] = os.path.join(dir, prog)
 		for prog in lstprogs:
@@ -90,7 +92,7 @@ class Printer(object):
 		else:
 			if options.options['printer.preview']:
 				if options.options['printer.softpath'] == 'none':
-					prog = self._findInPath(['xpdf', 'evince', 'gpdf', 'kpdf'])
+					prog = self._findInPath(['evince', 'xpdf', 'gpdf', 'kpdf'])
 					def opener(fn):
 						os.spawnv(os.P_NOWAIT, prog, (os.path.basename(prog),fn))
 					return opener
