@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: record.py 4044 2006-09-05 14:06:27Z ged $
+# $Id: record.py 4398 2006-11-02 21:54:22Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -201,7 +201,6 @@ class ModelRecord(signal_event.signal_event):
 	def expr_eval(self, dom):
 		if not isinstance(dom, basestring):
 			return dom
-
 		self._check_load()
 		d = {}
 		for name, mfield in self.fields.items():
@@ -210,6 +209,7 @@ class ModelRecord(signal_event.signal_event):
 
 		d['current_date'] = time.strftime('%Y-%m-%d')
 		d['time'] = time
+		d['context'] = self.context_get()
 		if self.parent:
 			d['parent'] = EvalEnvironment(self.parent)
 		val = eval(dom, d)
@@ -219,13 +219,14 @@ class ModelRecord(signal_event.signal_event):
 	# Shoud use changes of attributes (ro, ...)
 	#
 	def on_change(self, callback):
-		match = re.match('(.*)\((.*)\)', callback)
+		match = re.match('^(.*?)\((.*)\)$', callback)
 		if not match:
 			raise 'ERROR: Wrong on_change trigger: %s' % callback
 		func_name = match.group(1)
 		arg_names = [n.strip() for n in match.group(2).split(',')]
 		args = [self.expr_eval(arg) for arg in arg_names]
-		response = getattr(self.rpc, func_name)(False, *args)
+		ids = self.id and [self.id] or []
+		response = getattr(self.rpc, func_name)(ids, *args)
 		self.set(response.get('value', {}), modified=True)
 		if 'domain' in response:
 			for fieldname, value in response['domain'].items():
