@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: screen.py 3452 2006-06-29 17:03:25Z pinky $
+# $Id: screen.py 4698 2006-11-27 12:30:44Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -40,8 +40,9 @@ import signal_event
 import tools
 
 class Screen(signal_event.signal_event):
-	def __init__(self, model_name, view_ids=[], view_type=['form','tree'], parent=None, context={}, views_preload={}, tree_saves=True, domain=[], create_new=False, row_activate=None):
+	def __init__(self, model_name, view_ids=[], view_type=['form','tree'], parent=None, context={}, views_preload={}, tree_saves=True, domain=[], create_new=False, row_activate=None, hastoolbar=False):
 		super(Screen, self).__init__()
+		self.hastoolbar = hastoolbar
 		if not row_activate:
 			self.row_activate = self.switch_view
 		else:
@@ -140,17 +141,17 @@ class Screen(signal_event.signal_event):
 			self.current_model.validate_set()
 		self.display()
 
-	def add_view_custom(self, arch, fields, display=False):
-		return self.add_view(arch, fields, display, True)
+	def add_view_custom(self, arch, fields, display=False, toolbar={}):
+		return self.add_view(arch, fields, display, True, toolbar=toolbar)
 
 	def add_view_id(self, view_id, view_type, display=False):
 		if view_type in self.views_preload:
-			return self.add_view(self.views_preload[view_type]['arch'], self.views_preload[view_type]['fields'], display)
+			return self.add_view(self.views_preload[view_type]['arch'], self.views_preload[view_type]['fields'], display, toolbar=self.views_preload[view_type].get('toolbar', False))
 		else:
-			view = self.rpc.fields_view_get(view_id, view_type, self.context)
-			return self.add_view(view['arch'], view['fields'], display)
+			view = self.rpc.fields_view_get(view_id, view_type, self.context, self.hastoolbar)
+			return self.add_view(view['arch'], view['fields'], display, toolbar=view.get('toolbar', False))
 		
-	def add_view(self, arch, fields, display=False, custom=False):
+	def add_view(self, arch, fields, display=False, custom=False, toolbar={}):
 		def _parse_fields(node, fields):
 			if node.nodeType == node.ELEMENT_NODE:
 				if node.localName=='field':
@@ -159,7 +160,12 @@ class Screen(signal_event.signal_event):
 						if attrs['widget']=='one2many_list':
 							attrs['widget']='one2many'
 						attrs['type'] = attrs['widget']
-					fields[attrs['name']].update(attrs)
+					try:
+						fields[attrs['name']].update(attrs)
+					except:
+						print "-"*30,"\n malformed tag for :", attrs
+						print "-"*30
+						raise						
 			for node2 in node.childNodes:
 				_parse_fields(node2, fields)
 		dom = xml.dom.minidom.parseString(arch)
@@ -177,7 +183,7 @@ class Screen(signal_event.signal_event):
 
 		parser = widget_parse(parent=self.parent)
 		dom = xml.dom.minidom.parseString(arch)
-		view = parser.parse(self, dom, self.fields)
+		view = parser.parse(self, dom, self.fields, toolbar=toolbar)
 
 		self.views.append(view)
 
@@ -252,6 +258,8 @@ class Screen(signal_event.signal_event):
 	#
 	def reload(self):
 		self.current_model.reload()
+		if self.parent:
+			self.parent.reload()
 		self.display()
 
 	def remove(self, unlink = False):
