@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: binary.py 3614 2006-08-01 15:25:20Z ged $
+# $Id: binary.py 4752 2006-12-01 15:11:37Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -41,7 +41,7 @@ class wid_binary(interface.widget_interface):
 		interface.widget_interface.__init__(self, window, parent, model, attrs)
 		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_binary")
 		self.win_gl.signal_connect('on_but_new_clicked', self.sig_new)
-		self.win_gl.signal_connect('on_but_open_clicked', self.sig_open)
+#		self.win_gl.signal_connect('on_but_open_clicked', self.sig_open)
 		self.win_gl.signal_connect('on_but_remove_clicked', self.sig_remove)
 		self.win_gl.signal_connect('on_but_save_as_clicked', self.sig_save_as)
 		self.widget = self.win_gl.get_widget('widget_binary')
@@ -49,6 +49,16 @@ class wid_binary(interface.widget_interface):
 		self.wid_text = self.win_gl.get_widget('ent_binary')
 		self.model_field = False
 		
+	def _readonly_set(self, value):
+		if value:
+			self.win_gl.get_widget('but_new').hide()
+#			self.win_gl.get_widget('but_open').hide()
+			self.win_gl.get_widget('but_remove').hide()
+		else:
+			self.win_gl.get_widget('but_new').show()
+#			self.win_gl.get_widget('but_open').show()
+			self.win_gl.get_widget('but_remove').show()
+
 	def sig_new(self, widget=None):
 		try:
 			filename = common.file_selection(_('Select the file to attach'))
@@ -63,15 +73,16 @@ class wid_binary(interface.widget_interface):
 	def sig_save_as(self, widget=None):
 		try:
 			filename = common.file_selection(_('Save attachment as...'))
-			fp = file(filename,'wb+')
-			fp.write(base64.decodestring(self.model_field.get()))
-			fp.close()
+			if filename:
+				fp = file(filename,'wb+')
+				fp.write(base64.decodestring(self.model_field.get()))
+				fp.close()
 		except:
 			common.message(_('Error writing the file!'))
 
-	def sig_open(self, widget=None):
-		fname = self.attrs.get('fname_widget', False)
-		common.start_content(base64.decodestring(self.model_field.get()), fname)
+#	def sig_open(self, widget=None):
+#		fname = self.attrs.get('fname_widget', False)
+#		common.start_content(base64.decodestring(self.model_field.get()), fname)
 
 	def sig_remove(self, widget=None):
 		self.model_field.set_client(False)
