@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: form.py 3935 2006-08-28 16:59:25Z pinky $
+# $Id: form.py 4698 2006-11-27 12:30:44Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -51,6 +51,10 @@ class Button(Observable):
 #		if 'icon' in attrs:
 #			args['stock'] = eval('gtk.'+attrs['icon'])
 		self.widget = gtk.Button(**args)
+		if attrs.get('icon', False):
+			icon = gtk.Image()
+			icon.set_from_stock(attrs['icon'], gtk.ICON_SIZE_BUTTON)
+			self.widget.set_image(icon)
 #		self.widget.set_use_stock(True)
 #		self.widget.set_label(args['label'])
 
@@ -190,7 +194,11 @@ class parser_form(widget.view.interface.parser_interface):
 			if not node.nodeType==node.ELEMENT_NODE:
 				continue
 			attrs = tools.node_attributes(node)
-			if node.localName=='separator':
+			if node.localName=='image':
+				icon = gtk.Image()
+				icon.set_from_stock(attrs['name'], gtk.ICON_SIZE_DIALOG)
+				container.wid_add(icon,colspan=int(attrs.get('colspan',1)),expand=int(attrs.get('expand',0)), ypadding=10, help=attrs.get('help', False))
+			elif node.localName=='separator':
 				vbox = gtk.VBox()
 				if 'string' in attrs:
 					l = gtk.Label(attrs.get('string', 'No String Attr.'))
@@ -208,6 +216,11 @@ class parser_form(widget.view.interface.parser_interface):
 							text += node.toxml()
 				label = gtk.Label(text)
 				label.set_use_markup(True)
+				if 'align' in attrs:
+					try:
+						label.set_alignment(float(attrs['align'] or 0.0), 0.5)
+					except:
+						pass
 				if 'angle' not in attrs:
 					label.set_line_wrap(True)
 				label.set_angle(int(attrs.get('angle', 0)))
