@@ -32,6 +32,7 @@ from gtk import glade
 import wid_common
 
 import rpc
+import common
 
 _attrs_boolean = {
 	'required': False,
@@ -56,10 +57,15 @@ class widget_interface(object):
 		pass
 
 	def _menu_sig_default_get(self):
-		model = self._view.modelfield.parent.resource
-		res = rpc.session.rpc_exec_auth('/object', 'execute', model, 'default_get', [self.attrs['name']])
-		model = self._view.modelfield.set(res.get(self.attrs['name'], False))
-		self.display(self._view.modelfield)
+		try:
+			model = self._view.modelfield.parent.resource
+			res = rpc.session.rpc_exec_auth_try('/object', 'execute', model, 'default_get', [self.attrs['name']])
+			model = self._view.modelfield.set(res.get(self.attrs['name'], False))
+			self.display(self._view.modelfield)
+		except:
+			common.warning('You can not set to the default value here !', 'Operation not permited')
+			return False
+		print 'LA'
 
 	def sig_activate(self, widget=None):
 		# emulate a focus_out so that the onchange is called if needed
