@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: many2one.py 3937 2006-08-28 19:43:34Z pinky $
+# $Id: many2one.py 4773 2006-12-05 11:01:20Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -48,9 +48,11 @@ import service
 
 
 class dialog(object):
-	def __init__(self, model, id=None):
+	def __init__(self, model, id=None, attrs={}):
 		self.win_gl = glade.XML(common.terp_path("terp.glade"), "dia_form_win_many2one", gettext.textdomain())
 		self.dia = self.win_gl.get_widget('dia_form_win_many2one')
+		if ('string' in attrs) and attrs['string']:
+			self.dia.set_title(self.dia.get_title() + ' - ' + attrs['string'])
 		self.sw = self.win_gl.get_widget('many2one_vp')
 
 		self.screen = Screen(model)
@@ -181,7 +183,7 @@ class many2one(interface.widget_interface):
 		value = self._view.modelfield.get()
 
 		if value:
-			dia = dialog(self.attrs['relation'], self._view.modelfield.get())
+			dia = dialog(self.attrs['relation'], self._view.modelfield.get(), attrs=self.attrs)
 			ok, value = dia.run()
 			if ok:
 				self._view.modelfield.set_client(value)
@@ -208,7 +210,7 @@ class many2one(interface.widget_interface):
 		self.ok=True
 
 	def sig_new(self, *args):
-		dia = dialog(self.attrs['relation'])
+		dia = dialog(self.attrs['relation'], attrs=self.attrs)
 		ok, value = dia.run()
 		if ok:
 			self._view.modelfield.set_client(value)
