@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: one2many_list.py 3452 2006-06-29 17:03:25Z pinky $
+# $Id: one2many_list.py 4773 2006-12-05 11:01:20Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -43,6 +43,8 @@ class dialog(object):
 	def __init__(self, model_name, parent, model=None, attrs={}):
 		self.win_gl = glade.XML(common.terp_path("terp.glade"),"dia_form_win_many2one",gettext.textdomain())
 		self.dia = self.win_gl.get_widget('dia_form_win_many2one')
+		if ('string' in attrs) and attrs['string']:
+			self.dia.set_title(self.dia.get_title() + ' - ' + attrs['string'])
 		self.sw = self.win_gl.get_widget('many2one_vp')
 		self.screen = Screen(model_name, view_type=[], parent=parent)
 		if not model:
@@ -148,21 +150,23 @@ class one2many_list(interface.widget_interface):
 		self.win_gl.get_widget('o2m_but_open').set_sensitive(not value)
 
 	def _sig_new(self, *args):
-		if (self.screen.current_view.view_type=='form') or self.screen.editable_get():
-			self.screen.new()
-			self.screen.current_view.widget.set_sensitive(True)
-		else:
-			#self._view.modelfield.parent
-			parent = self._view.modelfield.parent
-			ok = 1
-			dia = dialog(self.attrs['relation'], parent=parent, attrs=self.attrs) #screen.current_model.parent)
-			while ok:
-				ok, value = dia.run()
-				if ok:
-					self.screen.models.model_add(value)
-					self.screen.display()
-					dia.new()
-			dia.destroy()
+		_, event = args
+		if event.type == gtk.gdk.BUTTON_PRESS :
+			if (self.screen.current_view.view_type=='form') or self.screen.editable_get():
+				self.screen.new()
+				self.screen.current_view.widget.set_sensitive(True)
+			else:
+				#self._view.modelfield.parent
+				parent = self._view.modelfield.parent
+				ok = 1
+				dia = dialog(self.attrs['relation'], parent=parent, attrs=self.attrs) #screen.current_model.parent)
+				while ok:
+					ok, value = dia.run()
+					if ok:
+						self.screen.models.model_add(value)
+						self.screen.display()
+						dia.new()
+				dia.destroy()
 
 	def _sig_edit(self, *args):
 		dia = dialog(self.attrs['relation'], parent=self.screen.current_model.parent,  model=self.screen.current_model, attrs=self.attrs)
@@ -171,15 +175,21 @@ class one2many_list(interface.widget_interface):
 #		self.screen.display()
 
 	def _sig_next(self, *args):
-		self.screen.display_next()
+		_, event = args
+		if event.type == gtk.gdk.BUTTON_PRESS:
+			self.screen.display_next()
 
 	def _sig_previous(self, *args):
-		self.screen.display_prev()
+		_, event = args
+		if event.type == gtk.gdk.BUTTON_PRESS:
+			self.screen.display_prev()
 
 	def _sig_remove(self, *args):
-		self.screen.remove()
-		if not self.screen.models.models:
-			self.screen.current_view.widget.set_sensitive(False)
+		_, event = args
+		if event.type == gtk.gdk.BUTTON_PRESS:
+			self.screen.remove()
+			if not self.screen.models.models:
+				self.screen.current_view.widget.set_sensitive(False)
 
 	def _sig_label(self, screen, signal_data):
 		name = '_'
