@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: selection.py 3946 2006-08-28 23:23:03Z pinky $
+# $Id: selection.py 4748 2006-12-01 13:16:26Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -47,11 +47,13 @@ class selection(interface.widget_interface):
 		self.widget.child.connect('changed', self.sig_changed)
 		self.widget.child.set_editable(False)
 		self.widget.child.connect('button_press_event', self._menu_open)
+		self.widget.child.connect('key_press_event', self.sig_key_pressed)
 		#self.widget.set_has_frame(False)
 
 		self.ok = True
 		self._selection={}
 		self.set_popdown(attrs.get('selection',[]))
+		self.last_key = (None, 0)
 
 	def set_popdown(self, selection):
 		model = gtk.ListStore(gobject.TYPE_STRING)
@@ -61,9 +63,13 @@ class selection(interface.widget_interface):
 			name = str(j)
 			lst.append(name)
 			self._selection[name]=i
+		self.key_catalog = {}
 		for l in lst:
 			i = model.append()
 			model.set(i, 0, l)
+			if l:
+				key = l[0].lower()
+				self.key_catalog.setdefault(key,[]).append(i)
 		self.widget.set_model(model)
 		self.widget.set_text_column(0)
 		return lst
@@ -109,5 +115,15 @@ class selection(interface.widget_interface):
 		#	if self.ok:
 		#		self.attrson_change(self.attrs['on_change'])
 
+	def sig_key_pressed(self, *args):
+		key = args[1].string.lower()
+		if self.last_key[0] == key:
+			self.last_key[1] += 1
+		else:
+			self.last_key = [ key, 1 ]
+		if not self.key_catalog.has_key(key):
+			return
+		self.widget.set_active_iter(self.key_catalog[key][self.last_key[1] % len(self.key_catalog[key])])
+
 	def _color_widget(self):
 		return self.widget.child
