@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: editabletree.py 3935 2006-08-28 16:59:25Z pinky $
+# $Id: editabletree.py 4776 2006-12-05 13:21:09Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -55,6 +55,7 @@ class EditableTreeView(gtk.TreeView, observator.Observable):
 		try:
 			real_value = cell.value_from_text(current_model, value)
 			modelfield.set_client(real_value)
+			modelfield.modified = False
 		except parser.UnsettableColumn:
 			return
 
@@ -67,14 +68,19 @@ class EditableTreeView(gtk.TreeView, observator.Observable):
 		#if modelfield.attrs.get('change_default', False):
 		#	current_model.cond_default(fieldname, real_value)
 
-	def on_open_remote(self, current_model, fieldname, create):
+	def on_open_remote(self, current_model, fieldname, create, value):
 		modelfield = current_model[fieldname]
 		col_type = modelfield.attrs['type']
 		cell = parser.Cell(col_type)(fieldname)
+		if value != cell.get_textual_value(current_model) or not value:
+			changed = True
+		else:
+			changed=False
 		try:
-			valid, value = cell.open_remote(current_model, create)
+			valid, value = cell.open_remote(current_model, create, changed, value)
 			if valid:
 				modelfield.set_client(value)
+				modelfield.modified = False
 		except NotImplementedError:
 			pass
 
@@ -116,9 +122,21 @@ class EditableTreeView(gtk.TreeView, observator.Observable):
 		model = store.get_value(store.get_iter(path), 0)
 		
 		if event.keyval in self.leaving_events:
+			shift_pressed = bool(gtk.gdk.SHIFT_MASK & event.state)
 			if isinstance(entry, gtk.Entry):
 				txt = entry.get_text()
-			elif isinstance(entry, gtk.ComboBoxEntry):
+			elif isinstance(entry, gtk.ComboBoxEntry) and shift_pressed and event.keyval != gtk.keysyms.ISO_Left_Tab:
+				model = entry.get_property('model')
+				txt = entry.get_active_text()
+				for idx, line in enumerate(model):
+					if line[1] == txt:
+						break
+				if event.keyval == gtk.keysyms.Up:
+					entry.set_active((idx - 1) % 3)
+				elif event.keyval == gtk.keysyms.Down:
+					entry.set_active((idx + 1) % 3)
+				return True
+			else:
 				txt = entry.get_active_text()
 			self.on_quit_cell(model, column.name, txt)
 		if event.keyval in self.leaving_model_events:
@@ -164,12 +182,17 @@ class EditableTreeView(gtk.TreeView, observator.Observable):
 			self.screen.display()
 			self.set_cursor(path, column, False)
 		elif event.keyval in (gtk.keysyms.F1, gtk.keysyms.F2):
+			if isinstance(entry, gtk.Entry):
+				value=entry.get_text()
+			else:
+				value=get_active_text()
 			self.on_open_remote(model, column.name,
-								create=(event.keyval==gtk.keysyms.F1))
+								create=(event.keyval==gtk.keysyms.F1), value=value)
 			self.set_cursor(path, column, True)
 		else:
-			modelfield = model[column.name]
-			modelfield.modified = True
+			if event.keyval >= 48 and event.keyval <= 200:
+				modelfield = model[column.name]
+				modelfield.modified = True
 			return False
 
 		return True
@@ -194,6 +217,9 @@ class EditableTreeView(gtk.TreeView, observator.Observable):
 		path, column = self.get_cursor()
 		store = self.get_model()
 		model = store.get_value(store.get_iter(path), 0)
-		self.on_quit_cell(model, column.name, entry.get_text())
+		if isinstance(entry, gtk.Entry):
+			self.on_quit_cell(model, column.name, entry.get_text())
+		elif isinstance(entry, gtk.ComboBoxEntry):
+			self.on_quit_cell(model, column.name, entry.get_active_text())
 
 # vim:noexpandtab:
