@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: parser.py 3607 2006-08-01 11:52:41Z pinky $
+# $Id: parser.py 4776 2006-12-05 13:21:09Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -91,14 +91,25 @@ class parser_tree(interface.parser_interface):
 				col._type = fields[fname]['type']
 				col.set_cell_data_func(renderer, cell.setter)
 				col.set_clickable(True)
+				twidth = {
+					'integer': 60,
+					'float': 80,
+					'date': 70,
+					'datetime': 120,
+					'selection': 90,
+					'char': 100,
+					'one2many': 50,
+				}
+				if 'width' in fields[fname]:
+					width = int(fields[fname]['width'])
+				else:
+					width = twidth.get(fields[fname]['type'], 100)
+				col.set_min_width(width)
 				col.connect('clicked', sort_model, treeview)
 				col.set_resizable(True)
 				treeview.append_column(col)
 		return treeview, {}, [], on_write
 
-#	def editing_canceled(self, cell_renderer):
-#		print self.treeview.on_editing_done(cell_renderer)
-
 class UnsettableColumn(Exception):
 	pass
 
@@ -184,8 +195,8 @@ class Datetime(GenericDate):
 
 class Float(Char):
 	def get_textual_value(self, model):
-#		_, digit = self.attrs['digits']
-		return locale.format('%.2f', model[self.field_name].get_client() or 0.0)
+		_, digit = self.attrs.get('digits', (16,2) )
+		return locale.format('%.'+str(digit)+'f', model[self.field_name].get_client() or 0.0)
 
 	def value_from_text(self, model, text):
 		return locale.atof(text)
@@ -208,18 +219,24 @@ class M2O(Char):
 							 domain=domain, context=context)
 		return names[0]
 
-	def open_remote(self, model, create=True):
+	def open_remote(self, model, create=True, changed=False, text=None):
 		modelfield = model[self.field_name]
 		relation = modelfield.attrs['relation']
 		
 		if create:
 			id = None
-		elif modelfield.internal:
+		elif modelfield.internal and not modelfield.modified and not changed:
 			id = modelfield.internal[0]
 		else:
-			searched = self.search_remote(relation,
-								 domain=modelfield.domain_get(),
-								 context=modelfield.context_get())
+			rpc = RPCProxy(relation)
+
+			domain=modelfield.domain_get()
+			context=modelfield.context_get()
+
+			names = rpc.name_search(text, domain, 'ilike', context)
+			if len(names) == 1:
+				return True, names[0]
+			searched = self.search_remote(relation, [x[0] for x in names], domain=domain, context=context)
 			if searched[0]:
 				return True, searched
 			return False, False
