@@ -97,7 +97,7 @@ class parse(object):
 			self.title = attrs.get('string','Form')
 			self.container.new(self.col)
 		elif name=='field':
-			if attrs.get('select', False):
+			if attrs.get('select', False) or self.fields[attrs['name']].get('select', False):
 				type = attrs.get('widget', self.fields[attrs['name']]['type'])
 				self.fields[attrs['name']].update(attrs)
 				self.fields[attrs['name']]['model']=self.model
